@@ -1,21 +1,34 @@
 #!/pro/bin/perl
 
-use strict;
+use 5.12.0;
 use warnings;
 
-our $VERSION = "0.02 - 20180404";
+our $VERSION = "0.05 - 20201001";
 
 -d ".git" or exit 0;
 
-my @m = stat "Checklist.md";
-my @p = stat "Checklist.pod";
+my $fmd  = "Checklist.md";
+my $fpod = $fmd =~ s/md$/pod/r;
+
+my %c = map  { $_ => (stat $_)[9] } $fmd, $fpod;
+$c{$fmd} && $c{$fpod} && $c{$fpod} - $c{$fmd} > 2 and
+    die "Did you edit $fpod instead of $fmd\n";
+
+my @m = stat $fmd;
+my @p = stat $fpod;
 my @t = stat $0;
 
 $m[9] && $p[9] && $p[9] >= $m[9] && $p[9] >= $t[9] and exit 0;
 
-use Markdown::Pod;
+my $mdp = eval { require Markdown::Pod; 1; };
+unless ($mdp) {
+    warn "Markdown::Pod cannot be loaded\n$fpod cannot be generated\n";
+    exit (0);
+    }
 
-open my $fh, "<", "Checklist.md";
+say "Converting $fmd to $fpod";
+
+open my $fh, "<", $fmd;
 my $md = do { local $/; <$fh> };
 close $fh;
 
@@ -36,7 +49,10 @@ $pod =~ s{=item -\K\n\n}{ }g;
 $pod =~ s{[ \t]+\n}{\n}g;
 $pod =~ s{\n\n\K\n+}{}g;
 
-open my $ph, ">", "Checklist.pod";
+open my $ph, ">", $fpod;
 print $ph "=encoding utf-8\n\n";
 print $ph $pod;
 close $ph;
+
+my $t = (stat $fmd)[9] + 1;
+utime $t, $t, $fpod;
