@@ -3,11 +3,12 @@
 use 5.20.0;
 use warnings;
 
-our $VERSION = "1.29 - 2018-04-21";
+our $VERSION = "1.33 - 2020-11-13";
+our $CMD = $0 =~ s{.*/}{}r;
 
 sub usage {
     my $err = shift and select STDERR;
-    say "usage: $0 [-v] [--git=author] [--travis=id] AUTHOR\n";
+    say "usage: $CMD [-v] [--git=author] [--travis=id] AUTHOR\n";
     exit $err;
     } # usage
 
@@ -19,6 +20,7 @@ GetOptions (
       "time!"		=> \my $opt_t,
     "g|git=s"		=> \my $git_id,
     "t|travis=s"	=> \my $travis_id,
+    "s|svg!"		=> \my $opt_svg,
     ) or usage (1);
 
 my $author = shift or usage (1);
@@ -31,6 +33,7 @@ use JSON::XS;
 use YAML::Tiny;
 use Data::Peek;
 use LWP::UserAgent;
+use HTML::Entities;
 use HTML::TreeBuilder;
 use List::Util  qw( sum0 );
 use Encode      qw( encode decode );
@@ -97,9 +100,9 @@ close $html;
 sub href {
     my ($txt, $ref, $ttl, $dtl) = (@_, "", "", "");
     if (ref $txt eq "HASH") {
-	$ttl = $txt->{title};
-	$dtl = $txt->{dtitle};
-	$txt = $txt->{text};
+	$ttl = encode_entities ($txt->{title});
+	$dtl = encode_entities ($txt->{dtitle});
+	$txt = encode_entities ($txt->{text});
 	}
     $ttl //= "";
     $dtl //= "";
@@ -155,10 +158,10 @@ sub modules {
             <th>vsn</th>
             <th class="rhdr">released</th>
             <th class="tci" colspan="4"><a href="https://github.com/$git_id">repo</a></th>
-            <th class="rhdr"><a href="http://rt.cpan.org/Public/Dist/ByMaintainer.html?Name=$author">RT</a></th>
+            <th class="rhdr"><a href="https://rt.cpan.org/Public/Dist/ByMaintainer.html?Name=$author">RT</a></th>
             <th class="center">doc</th>
             <th class="tci"><a href="https://travis-ci.org/profile/$travis_id">TravisCI</a></th>
-            <th class="cpants"><a href="http://cpants.perl.org/author/$author">kwalitee</a></th>
+            <th class="cpants"><a href="https://cpants.perl.org/author/$author">kwalitee</a></th>
             <th class="rhdr"><a href="http://cpancover.com">cover</a></th>
             <th class="rhdr" colspan="3"><a href="http://www.cpantesters.org/author/$auid1/$author.html">cpantesters</a></th>
             <th class="rhdr"><span style="color: green">&#x2714;</span><span style="color: red">&#x2718;</span></th>
@@ -203,7 +206,7 @@ EOH
 	    $opt_v > 1 and warn " Fetch rating\n";
 	    my $n = $rs->total;
 	    if ($r = $rs->next) {
-		$rating = "http://cpanratings.perl.org/d/$dist";
+		$rating = "https://cpanratings.perl.org/d/$dist";
 		$data->{rating} = {
 		    text   => $r->{_source}{rating},
 		    dtitle => "$n votes",
@@ -219,21 +222,37 @@ EOH
 
 	# Kwalitee
 	my $kwtc = "none";
+	if ($opt_svg) {
+	    my $svg_url = "https://cpants.cpanauthors.org/dist/$dist.svg";
+	    $r = $ua->get ($svg_url);
+	    $r && $r->is_success and $data->{kwalitee} = qq{<img src="$svg_url" />};
+	    }
 	unless (defined $data->{kwalitee}) {
 	    $opt_v > 1 and warn " Fetch kwalitee\n";
-	    ($r = $ua->get ("http://cpants.cpanauthors.org/dist/$dist")) &&
-	     $r->is_success && $r->content =~ m{
-		<dt> [\s\r\n]*  Kwalitee          [\s\r\n]* </dt> [\s\r\n]*
-		<dd> [\s\r\n]* ([0-9.]+)          [\s\r\n]* </dd> [\s\r\n]*
-		<dt> [\s\r\n]*  Core \s* Kwalitee [\s\r\n]* </dt> [\s\r\n]*
-		<dd> [\s\r\n]* ([0-9.]+)          [\s\r\n]* </dd>
-		}xi and ($data->{kwk}, $data->{kwc}) = ($1, $2);
-	     $data->{kwalitee} = join " / " =>
-		 $data->{kwc} // "-", $data->{kwk} // "&nbsp;&nbsp;&nbsp;-&nbsp;&nbsp;";
-	     $data->{kwc} and $kwtc = $data->{kwc} >= 100 ? "pass"
-				    : $data->{kwc} >=  80 ? "na"
-				    : $data->{kwc} >=  60 ? "warn" : "fail";
-	     }
+	    $r = $ua->get ("https://cpants.cpanauthors.org/dist/$dist");
+	    my $tree = HTML::TreeBuilder->new;
+	    $tree->parse_content ($r && $r->is_success ? decode ("utf-8", $r->content) : "");
+	    if (my ($dl) = $tree->look_down (_tag => "dl", class => "small")) {
+		my ($dt, %dl) = ("");
+		foreach my $d ($dl->look_down (_tag => qr{^d[td]$})) {
+		    my $txt = $d->as_text;
+		    if ($d->tag eq "dt") {
+			$dt = lc $txt;
+			next;
+			}
+		    $dl{$dt} //= $txt;
+		    }
+		$data->{kwk} = $dl{"kwalitee"};
+		$data->{kwc} = $dl{"core kwalitee"};
+		$data->{kwr} = $dl{"release date"};
+
+		$data->{kwalitee} = join " / " =>
+		    $data->{kwc} || "-", $data->{kwk} || "&nbsp;&nbsp;&nbsp;-&nbsp;&nbsp;";
+		$data->{kwc} and $kwtc = $data->{kwc} >= 100 ? "pass"
+				       : $data->{kwc} >=  80 ? "na"
+				       : $data->{kwc} >=  60 ? "warn" : "fail";
+		}
+	    }
 	$time{kwalitee} += t_used;
 
 	# GIT repo and last commit
@@ -283,8 +302,7 @@ EOH
 	$time{cpantesters} += t_used;
 
 	# RT tickets
-	my $rt = $m->{rt} // "http://rt.cpan.org/Public/Dist/Display.html?Name=$dist";
-	# http://rt.cpan.org/NoAuth/Bugs.html?Dist=$dist"; - does not work anymore
+	my $rt = $m->{rt} // "https://rt.cpan.org/Public/Dist/Display.html?Name=$dist";
 	# https://rt.cpan.org/Dist/Display.html?Name=$dist";
 	# https://rt.cpan.org/Dist/Display.html?Queue=DBD%3A%3ACSV
 	my $rt_tag = "*";
@@ -360,7 +378,7 @@ EOH
 	    }
 	$time{github} += t_used;
 	$rt_tag =~ m/^[-0-9]?$/ or
-	    $rt_tag = ($mcpd ? $mcpd->bugs->{rt}{active} // "" : "") // "*";
+	    $rt_tag = ($mcpd ? $mcpd->bugs->{rt}{active} // "" : "") || "*";
 	$time{rt_tag} += t_used;
 
 	# Downriver deps
@@ -427,7 +445,7 @@ EOH
 	    }
 	$time{travis} += t_used;
 	if ($tci_tag =~ m{^(?:unknown|\*|)$} && $git =~ m{\b github\.com \b}x) {
-	    $tci       = "$git/settings/hooks/new?service=travis";
+	    $tci       = "https://travis-ci.org/profile";
 	    $tci_tag   = "add";
 	    $tci_class = [ "tci", "gray" ];
 	    }
@@ -443,7 +461,7 @@ EOH
 	    branch	=> "-",
 	    condition	=> "-",
 	    pod		=> "-",
-	    statement	=> "&#x237d;", # SHOULDERED OPEN BOX (uncovered)
+	    statement	=> "\x{237d}", # SHOULDERED OPEN BOX (uncovered)
 	    subroutine	=> "-",
 	    total	=> "-",
 	    };
@@ -453,11 +471,11 @@ EOH
 	    $cvrr = "http://cpancover.com/latest/$dist-$data->{version}/index.html";
 	    }
 	my $cvrl = join " \n" => map {
-	    (sprintf "%-10s: %6s", $_, $data->{cover}{$_}) =~ s/ /\&nbsp;/gr;
+	    (sprintf "%-10s: %6s", $_, $data->{cover}{$_}) =~ s/ /\x{00a0}/gr; # NBSP
 	    } sort keys %{$data->{cover}};
 	my $cvrt = { text => $data->{cover}{statement}, dtitle => $cvrl };
 	my $cvrc = $data->{cover}{total} eq "-"        ? "none"
-	         : $data->{cover}{total} eq "&#x237d;" ? "none"
+	         : $data->{cover}{total} eq "\x{237d}" ? "none"
 	         : $data->{cover}{total} eq "n/a"      ? "none"
 		 : $data->{cover}{total} >= 90         ? "pass"
 		 : $data->{cover}{total} >= 70         ? "na"
@@ -476,7 +494,7 @@ EOH
 	dta (["rt"        ], $rt_tag,                 $rt);
 	dta (["center"    ], "doc",                   $m->{doc}    // "https://v1.metacpan.org/module/$mod");
 	dta ($tci_class,     $tci_tag || "-",         $tci);
-	dta (["kwt",$kwtc ], $data->{kwalitee},       $m->{cpants} // "http://cpants.cpanauthors.org/dist/$dist");
+	dta (["kwt",$kwtc ], $data->{kwalitee},       $m->{cpants} // "https://cpants.cpanauthors.org/dist/$dist");
 	dta (["cvr",$cvrc ], $cvrt,                   $cvrr);
 	dta (["cpt","pass"], $data->{cptst}[0] // "", $m->{ct}     // "http://www.cpantesters.org/show/$dist.html");
 	dta (["cpt","na"  ], $data->{cptst}[1] // "");
@@ -493,7 +511,7 @@ EOH
 
     print $html <<"EOH";
 
-          <tr><td colspan="19"><hr></td></tr>
+          <tr><td colspan="19"><hr /></td></tr>
           <tr>
             <td><a href="http://backpan.perl.org/authors/id/$auid3/$author/">BackPAN</a></td>
             <td colspan="11"><a href="http://analysis.cpantesters.org/?author=$author&amp;age=91.3&amp;SUBMIT_xxx=Submit">CPANTESTERS analysis</a></td>
@@ -511,16 +529,17 @@ EOH
 
 sub header {
     print $html <<"EOH";
-<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
-<html lang="en">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml" lang="en">
 <head>
-  <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
-  <meta name="Generator"          content="makewww.pl">
-  <meta name="Author"             content="H.Merijn Brand">
-  <meta name="Description"        content="Perl">
-  <title>$author Perl QA page</title>
+  <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
+  <meta name="Generator"          content="makewww.pl" />
+  <meta name="Author"             content="H.Merijn Brand" />
+  <meta name="Description"        content="Perl" />
+  <title>$author - Perl QA page</title>
 
-  <link rel="stylesheet" type="text/css"  href="tux.css">
+  <link rel="stylesheet" type="text/css"  href="tux.css" />
   </head>
 <body>
 
@@ -530,7 +549,7 @@ EOH
 
 sub footer {
     my @d = localtime;
-    my $stamp = sprintf "%02d-%02d-%04d", $d[3], $d[4] + 1, $d[5] + 1900;
+    my $stamp = sprintf "%04d-%02d-%02d", $d[5] + 1900, $d[4] + 1, $d[3];
     print $html <<"EOH";
 
   <tr class="boxed">
